@@ -1,5 +1,12 @@
+'''
+These are the things that are used when you `cytoplasm serve`.
+'''
+
 import os, cytoplasm, sys
 
+# get the configuration from cytoplasm.configuration
+config = cytoplasm.configuration.get_config()
+
 # make this work in either Python 2.x or 3.x
 if sys.version_info.major >= 3:
     from http.server import SimpleHTTPRequestHandler
@@ -9,14 +16,16 @@ else:
 # keep track of when things were last built in this global variable
 most_recent_time = 0
 
-def handler(rebuild):
+# does some beginning things and returns the handler to use;
+# you should give it a boolean meaning whether you want it to rebuild or not.
+def initialize(rebuild):
     # build once first...
     cytoplasm.build()
     # and save the most recent time
     global most_recent_time
     most_recent_time = most_recent(".")
     # change to the build directory, where things are to be served from.
-    os.chdir(cytoplasm.configuration.build_dir)
+    os.chdir(config.build_dir)
     if rebuild:
         # if rebuild is true, return the RebuildHandler
         return RebuildHandler
@@ -26,7 +35,7 @@ def handler(rebuild):
 
 def most_recent(directory):
     "Determine the most recent modified time in the source directory, ignoring dotfiles and _build."
-    build_dir = cytoplasm.configuration.build_dir
+    build_dir = config.build_dir
     # get the candidate files:
     files = [f for f in os.listdir(directory) if f != build_dir and not f.startswith(".")]
     # get each of their times
@@ -51,13 +60,10 @@ class RebuildHandler(SimpleHTTPRequestHandler):
             if new_recent > most_recent_time:
                 # update most_recent_time
                 most_recent_time = new_recent
-                # The following is an ugly hack:
-                # Move up one directory to the source directory
-                os.chdir("..")
                 # Build the site from the source directory
-                cytoplasm.build()
+                cytoplasm.build("..")
                 # and move back down to the build directory to continue serving.
-                os.chdir(cytoplasm.configuration.build_dir)
+                os.chdir(config.build_dir)
             # Copy the file to self.wfile...
             self.copyfile(f, self.wfile)
             # and then close it.
